{% extends "base.html" %} {% block main %}

## Examples

Each example offers links to the different renderers / platforms on which it is available. For instance, the hello static example is available for web, local, and static. The web examples will open in a browser-based editor where they can also be executed while others will link to code snippets.

### Basics

Hello static:A first hello world example available for all three renderers.
Web Local Static
Hello interactive: A hello world example with minimumn interactivity.
Web Local
Hello draw: The hello world example from the homepage.
Web Local
Hello basics: Basics of styling and colors.
Web Local Static
Hello stack: Saving (pushing) and loading (popping) styles.
Web Local Static

### Buffers

Buffer simple: Using simple buffers.
Web Local Static
Buffer opaque: Using fast opaque buffers.
Web Local Static

### Data

Read CSV: Rendering a simple bar chart from a CSV file.
Web Local Static
Read JSON: Drawing a simple bar chart from a JSON file.
Web Local Static
Write CSV: Generating a CSV file from a sketch.
Web Local Static
Write JSON: Generating a JSON file from a sketch.
Web Local Static

### Dialog

Simple dialogs: Simple dialogs like prompt and alert.
Web Local

### Geo

Geo transform: Drawing with map panning and zooming.
Web Local Static
Geo polygon: Drawing a polygon defined by latitude and longitude points.
Web Local Static
GeoJSON: Displaying GeoJSON on a map.
Web Local Static

### Images

Read image: Drawing an image into a sketch.
Web Local Static
Write image: Writing a sketch to an image file.
Web Local Static

### Inputs

Keyboard: Example of taking keyboard input.
Web Local
Mouse: Example of taking mouse input.
Web Local

### Shapes

Lines: Drawing lines.
Web Local Static
Pixels: Drawing individual pixels.
Web Local Static
Rectangles: Drawing rectangles and squares.
Web Local Static
Ellipses: Drawing ellipses and circles.
Web Local Static
Arcs: Drawing arcs.
Web Local Static
Shapes: Drawing complex shapes with lines.
Web Local Static
Curves: Drawing complex shapes with bezier curves.
Web Local Static

### Transformations

Translate: Moving the origin by translating.
Web Local Static
Scale: Zooming in and out by scaling.
Web Local Static
Rotate: Rotating around the origin.
Web Local Static
Combine transforms: Combining multiple transforms together.
Web Local Static
Transform stack: Saving (pushing) and loading (popping) transforms.
Web Local Static
{% endblock %}